#!/bin/bash -
PATH=/bin:/sbin:/usr/bin:/usr/sbin:/usr/local/bin:/usr/local/sbin:~/bin
export PATH
#===============================================================================
#   SYSTEM REQUIRED:  CentOS-5 (32bit/64bit)CentOS-6 (32bit/64bit)
#   DESCRIPTION:  Install LAMP in CentOS
#   AUTHOR: Zhu Maohao.
#   REVISION:  0.1
#   website: http://www.centos.bz/lamp/
#===============================================================================

#===============================================================================
#DESCRIPTION:Make sure only root can run our script
#USAGE:rootness
#===============================================================================
function rootness(){
# Make sure only root can run our script
if [[ $EUID -ne 0 ]]; then
   echo "This script must be run as root" 1>&2
   exit 1
fi
}

#===============================================================================
#DESCRIPTION:monitor if there is an error.
#USAGE:errors_control [error code] [package name]
#===============================================================================
function error_control(){
if [ $1 -eq 1 ] || [ $1 -eq 2 ];then
#if send errors file	
while true
do
read -p "failed to install $2!Do you allow send errors file to the writer?[y/n]" send
case $send in
y|Y|YES|yes|Yes)
send=y
break
;;
n|N|no|NO|No)
send=n
break
;;
*) echo Please enter only y or n
esac
done

#send errors file ...
if [ $send == "y" ];then
echo "sending errors file to the writer..."
service sendmail start >/dev/null
sleep 2
mailcontent=`cat /root/lamp_errors.log`
release=`cat /etc/redhat-release`
[ `getconf WORD_BIT` = '32' ] && [ `getconf LONG_BIT` = '64' ] && bit="64" || bit="32"
mailcontent=`printf "$release $bit $mailcontent"`
/usr/sbin/sendmail -t <<EOF
To: 452336092@qq.com
Subject: lamp errors reports
$mailcontent
EOF
fi
echo "Errors file:/root/lamp_errors.log.you can contact QQ452336092 to ask for help."
exit 1
fi
}
#===============================================================================
#DESCRIPTION:disable selinux.
#USAGE:disable_selinux
#===============================================================================
function disable_selinux(){
if [ -s /etc/selinux/config ] && grep 'SELINUX=enforcing' /etc/selinux/config; then
sed -i 's/SELINUX=enforcing/SELINUX=disabled/g' /etc/selinux/config
setenforce 0
fi
}
#===============================================================================
#DESCRIPTION:Pre-installation settings.
#USAGE:pre_installation_settings
#===============================================================================
function pre_installation_settings(){
#1-set mysql root password
	echo "Please input the root password of mysql:"
	read -p "(Default password: root):" mysqlrootpwd
	if [ "$mysqlrootpwd" = "" ]; then
		mysqlrootpwd="root"
	fi
echo "$mysqlrootpwd" >/root/my.cnf
#2-select which version of php you'll install
while true
do
echo "select which version of php you'll install"
echo "1) php-5.2.17"
echo "2) php-5.3.10"
read -p "Please input 1 or 2:" phpv
case $phpv in
1)
phpv=1
echo "Your choice:php-5.2.17"
break
;;
2)
phpv=2
echo "Your choice:php-5.3.10"
break
;;
*) echo Please enter only 1 or 2
esac
done

#3-select which version of mysql you'll install
while true
do
echo "select which version of mysql you'll install"
echo "1) mysql-5.1.61"
echo "2) mysql-5.5.20"
read -p "Please input 1 or 2:" mysqlv
case $mysqlv in
1)
mysqlv=1
echo "Your choice:mysql-5.1.61"
break
;;
2)
mysqlv=2
echo "Your choice:mysql-5.5.20"
break
;;
*) echo Please enter only 1 or 2
esac
done
#uninstall apache php httpd mysql
rpm -e httpd
rpm -e mysql
rpm -e php

yum -y remove httpd
yum -y remove php
yum -y remove mysql-server mysql
yum -y remove php-mysql

yum -y install yum-fastestmirror

#Set timezone
rm -rf /etc/localtime
\cp /usr/share/zoneinfo/Asia/Shanghai /etc/localtime
yum install -y ntp
ntpdate -d cn.pool.ntp.org

#if it is centos 6.0
cur_dir=`pwd`
cd $cur_dir
if cat /etc/redhat-release | grep '6..' ;then
if [ `getconf WORD_BIT` = '32' ] && [ `getconf LONG_BIT` = '64' ] ; then
rpm -ivh epel-release-6-5.noarch-64.rpm
else
rpm -ivh epel-release-6-5.noarch-32.rpm
fi
fi

#install some necessary tools
yum -y install gcc  gcc-c++ libtool-libs autoconf freetype-devel gd libjpeg-devel  libpng-devel libxml2-devel ncurses-devel zlib-devel zip unzip curl-devel wget crontabs iptables file bison patch mlocate flex diffutils automake make kernel-devel cpp readline-devel openssl-devel vim-minimal sendmail glibc-devel  glib2-devel bzip2-devel e2fsprogs-devel libidn-devel  gettext-devel expat-devel libcap-devel  libtool-ltdl-devel pam-devel libmcrypt-devel sendmail
cd $cur_dir
}
#===============================================================================
#DESCRIPTION:download files.
#USAGE:download_files [filename] [secondary url] 
#===============================================================================
function download_files(){
if [ -s $1 ]; then
  echo "$1 [found]"
  else
  echo "$1 not found!!!download now......"
 if ! wget -c --tries=3 http://centos.googlecode.com/files/$1 && ! wget -c --tries=3 $2;then
 echo "Failed to download $1,please download it to "$cur_dir" directory manually and rerun the install script."
 exit 1
 fi
fi
}
#===============================================================================
#DESCRIPTION:install apache2.
#USAGE:install_apache
#===============================================================================
function install_apache(){
if [ ! -d /usr/local/apache ];then
echo "============================apache2 install=================================="
echo "Start install apache2"
cd $cur_dir/untar/httpd-2.2.22
./configure --prefix=/usr/local/apache --with-included-apr --enable-so --enable-deflate=shared --enable-expires=shared  --enable-headers=shared --enable-rewrite=shared --enable-static-support --disable-actions --disable-cgi --disable-env --disable-filter --disable-imagemap --disable-include --disable-isapi --disable-negotiation --disable-nw_ssl --disable-setenvif --disable-status --disable-userdir 2>/root/lamp_errors.log
code=$?
error_control $code "httpd-2.2.22"
make 2>/root/lamp_errors.log
code=$?
error_control $code "httpd-2.2.22"
make install
\cp build/rpm/httpd.init /etc/init.d/httpd
chmod 755 /etc/init.d/httpd
chkconfig --add httpd
chkconfig httpd on
cd /etc
mv httpd httpd_old
ln -s /usr/local/apache/ httpd
cd /usr/sbin/
ln -fs /usr/local/apache/bin/httpd
ln -fs /usr/local/apache/bin/apachectl
cd /var/log
rm -rf httpd/
ln -s /usr/local/apache/logs httpd
groupadd apache
useradd -g apache apache
mkdir -p /home/www/default/
chmod -R 755 /home/www/default/
chown -R apache.apache /home/default
\cp -f $cur_dir/conf/httpd-vhosts.conf /etc/httpd/conf/extra/httpd-vhosts.conf
mkdir -p /usr/local/apache/conf/vhost/
\cp -f $cur_dir/conf/httpd-mpm.conf /usr/local/apache/conf/extra/httpd-mpm.conf
\cp -f $cur_dir/conf/httpd.conf /usr/local/apache/conf/httpd.conf
\cp -f $cur_dir/conf/index.html /home/www/default/index.html
\cp -f $cur_dir/conf/p.php /home/www/default/p.php
\cp -f $cur_dir/conf/phpinfo.php /home/www/default/phpinfo.php
echo "============================apache2 install completed=================================="
else
echo "apache had been installed!"
fi
}
#===============================================================================
#DESCRIPTION:install mysql.
#USAGE:install_mysql
#===============================================================================
function install_mysql(){
if [ ! -d /usr/local/mysql ];then
if [ $mysqlv == 1 ];then
#install MySQL5.1
echo "============================mysql5.1 install============================================"
cd $cur_dir/
tar xzf mysql-5.1.61.tar.gz -C $cur_dir/untar
groupadd mysql
useradd -g mysql mysql
cd $cur_dir/untar/mysql-5.1.61
./configure --prefix=/usr/local/mysql/ --localstatedir=/usr/local/mysql/data --without-debug --with-unix-socket-path=/tmp/mysql.sock --with-client-ldflags=-all-static --with-mysqld-ldflags=-all-static --enable-assembler --with-extra-charsets=gbk,gb2312,utf8 --with-pthread 2>/root/lamp_errors.log
code=$?
error_control $code "mysql-5.1.61"
make 2>/root/lamp_errors.log
code=$?
error_control $code "mysql-5.1.61"
make install
\cp -f $cur_dir/conf/my5.1.cnf /etc/my.cnf
/usr/local/mysql/bin/mysql_install_db --user=mysql
chown -R root /usr/local/mysql
chown -R mysql /usr/local/mysql/data
chgrp -R mysql /usr/local/mysql
 
/usr/local/mysql/bin/mysqld_safe  --user=mysql &
 
\cp $cur_dir/untar/mysql-5.1.61/support-files/mysql.server /etc/rc.d/init.d/mysqld
chown root.root /etc/rc.d/init.d/mysqld
chmod 755 /etc/rc.d/init.d/mysqld
chkconfig --add mysqld
chkconfig --list mysqld
chkconfig --levels 245 mysqld off
cat > /etc/ld.so.conf.d/mysql.conf<<EOF
/usr/local/mysql/lib/mysql
/usr/local/lib
EOF
ldconfig
if [ `getconf WORD_BIT` = '32' ] && [ `getconf LONG_BIT` = '64' ] ; then
ln -s /usr/local/mysql/lib/mysql /usr/lib64/mysql
else
ln -s /usr/local/mysql/lib/mysql /usr/lib/mysql
fi
ln -s /usr/local/mysql/bin/mysql /usr/bin
ln -s /usr/local/mysql/bin/mysqladmin /usr/bin
service mysqld start
/usr/local/mysql/bin/mysqladmin -u root password $mysqlrootpwd
mysql -uroot -p$mysqlrootpwd <<EOF
drop database test;
delete from mysql.user where user='';
update mysql.user set password=password('$mysqlrootpwd') where user='root';
delete from mysql.user where not (user='root') ;
flush privileges;
exit
EOF
if [ "$create" == "y" ];then
mysql -uroot -p$mysqlrootpwd <<EOF
CREATE DATABASE  IF NOT EXISTS \`$dbname\`;
GRANT ALL PRIVILEGES ON \`$dbname\` . * TO '$dbname'@'localhost' IDENTIFIED BY '$mysqlpwd';
GRANT ALL PRIVILEGES ON \`$dbname\` . * TO '$dbname'@'127.0.0.1' IDENTIFIED BY '$mysqlpwd';
flush privileges;
exit
EOF
fi
echo "============================mysql5.1 install completed============================================"
else
#install MySQL5.5
echo "============================mysql5.5 install============================================"
cd $cur_dir/
tar xzf mysql-5.5.20.tar.gz -C $cur_dir/untar
tar xzf cmake-2.8.7.tar.gz -C $cur_dir/untar
tar xzf bison-2.5.tar.gz -C $cur_dir/untar
#install cmake
cd $cur_dir/untar/cmake-2.8.7
./bootstrap
make
make install
#install bison-2.5
cd $cur_dir/untar/bison-2.5
./configure
make
make install
#install mysql5.5
/usr/sbin/groupadd mysql
/usr/sbin/useradd -g mysql mysql
cd $cur_dir/untar/mysql-5.5.20

cmake -DCMAKE_INSTALL_PREFIX=/usr/local/mysql -DMYSQL_UNIX_ADDR=/tmp/mysql.sock -DDEFAULT_CHARSET=utf8 -DDEFAULT_COLLATION=utf8_general_ci -DWITH_EXTRA_CHARSETS=all -DWITH_READLINE=1 -DENABLED_LOCAL_INFILE=1 2>/root/lamp_errors.log
code=$?
error_control $code "mysql-5.5.20"
make 2>/root/lamp_errors.log
code=$?
error_control $code "mysql-5.5.20"
make install
chmod +w /usr/local/mysql
chown -R mysql:mysql /usr/local/mysql
ln -s /usr/local/mysql/lib/libmysqlclient.so.16 /usr/lib/libmysqlclient.so.16
cd support-files/
cp $cur_dir/conf/my5.5.cnf /etc/my.cnf
cp mysql.server /etc/rc.d/init.d/mysqld

/usr/local/mysql/scripts/mysql_install_db \
--defaults-file=/etc/my.cnf \
--basedir=/usr/local/mysql \
--datadir=/usr/local/mysql/data \
--user=mysql

chmod +x /etc/init.d/mysqld
chkconfig --add mysqld
chkconfig --level 345 mysqld on
cat > /etc/ld.so.conf.d/mysql.conf<<EOF
/usr/local/mysql/lib/mysql
/usr/local/lib
EOF
ldconfig
if [ `getconf WORD_BIT` = '32' ] && [ `getconf LONG_BIT` = '64' ] ; then
ln -s /usr/local/mysql/lib/mysql /usr/lib64/mysql
else
ln -s /usr/local/mysql/lib/mysql /usr/lib/mysql
fi
ln -s /usr/local/mysql/bin/mysql /usr/bin
ln -s /usr/local/mysql/bin/mysqladmin /usr/bin
service mysqld start
/usr/local/mysql/bin/mysqladmin password $mysqlrootpwd
mysql -uroot -p$mysqlrootpwd <<EOF
drop database test;
delete from mysql.user where user='';
update mysql.user set password=password('$mysqlrootpwd') where user='root';
delete from mysql.user where not (user='root') ;
flush privileges;
exit
EOF
if [ "$create" == "y" ];then
mysql -uroot -p$mysqlrootpwd <<EOF
CREATE DATABASE  IF NOT EXISTS \`$dbname\`;
GRANT ALL PRIVILEGES ON \`$dbname\` . * TO '$dbname'@'localhost' IDENTIFIED BY '$mysqlpwd';
GRANT ALL PRIVILEGES ON \`$dbname\` . * TO '$dbname'@'127.0.0.1' IDENTIFIED BY '$mysqlpwd';
flush privileges;
exit
EOF
fi
echo "============================mysql5.5 install completed=================================="
fi
else
echo "mysql had been installed!"
fi
}
#===============================================================================
#DESCRIPTION:install php.
#USAGE:install_php
#===============================================================================
function install_php(){
if [ ! -d /usr/local/php ];then
if [ $phpv == 1 ];then
#install PHP5.2
echo "============================PHP5.2 install============================================"
if cat /etc/redhat-release | grep '6..' ;then
if [ `getconf WORD_BIT` = '32' ] && [ `getconf LONG_BIT` = '64' ] ; then
ln -s /usr/lib64/libjpeg.so /usr/lib/libjpeg.so
ln -s /usr/lib64/libpng.so /usr/lib/libpng.so
fi
fi
cd $cur_dir/
tar xzf php-5.2.17.tar.gz -C $cur_dir/untar
\cp $cur_dir/conf/php-5.2.17-max-input-vars.patch $cur_dir/untar/php-5.2.17/
cd $cur_dir/untar/php-5.2.17
patch -p1 < php-5.2.17-max-input-vars.patch
./configure --prefix=/usr/local/php  --with-apxs2=/usr/local/apache/bin/apxs --enable-discard-path --with-config-file-path=/etc --with-config-file-scan-dir=/etc/php.d --with-libxml-dir --with-zlib --with-curl --enable-ftp --with-gd --with-jpeg-dir --with-png-dir --with-zlib-dir --with-ttf --with-freetype-dir --enable-gd-native-ttf --with-gettext --enable-mbstring  --with-mime-magic --with-mysql=/usr/local/mysql  --without-pear --with-mcrypt --with-iconv=/usr/local/libiconv 2>/root/lamp_errors.log
code=$?
error_control $code
make 2>/root/lamp_errors.log
code=$?
error_control $code
make install
\cp -f $cur_dir/conf/php5.2.ini /etc/php.ini
mkdir /etc/php.d

echo "============================PHP5.2 install completed============================================"
else
#install PHP5.3
echo "============================PHP5.3 install============================================"
cd $cur_dir/
tar xzf php-5.3.10.tar.gz -C $cur_dir/untar
cd $cur_dir/untar/php-5.3.10
./configure --prefix=/usr/local/php --with-apxs2=/usr/local/apache/bin/apxs  --with-config-file-path=/etc --with-config-file-scan-dir=/etc/php.d  --with-libxml-dir --with-openssl --with-zlib --with-curl --enable-ftp --with-gd --with-jpeg-dir --with-png-dir --with-zlib-dir  --with-freetype-dir --enable-gd-native-ttf --with-gettext --enable-mbstring --with-mcrypt  --with-mysql=/usr/local/mysql --with-mysqli=/usr/local/mysql/bin/mysql_config --without-pear --with-iconv=/usr/local/libiconv 2>/root/lamp_errors.log
code=$?
error_control $code
make 2>/root/lamp_errors.log
code=$?
error_control $code
make install
cp $cur_dir/conf/php5.3.ini /etc/php.ini
mkdir /etc/php.d
echo "============================PHP5.3 install completed============================================"
fi

else
echo "PHP had been installed"
fi
}
#===============================================================================
#DESCRIPTION:install phpmyadmin.
#USAGE:install_phpmyadmin
#===============================================================================
function install_phpmyadmin(){
echo "============================phpmyadmin install============================================"
cd $cur_dir
mv untar/phpMyAdmin-3.4.9-all-languages /home/www/default/phpmyadmin
chmod -R 755 /home/www/default/phpmyadmin
chown -R apache:apache /home/www/default/phpmyadmin
cd /home/www/default/phpmyadmin
\cp -f $cur_dir/conf/config.inc.php /home/www/default/phpmyadmin/config.inc.php
secret=`cat /dev/urandom | head -1 | md5sum | head -c 16`
sed -i "s/.*blowfish_secret.*/\$cfg['blowfish_secret'] = '$secret';/g" /home/www/default/phpmyadmin/config.inc.php
service httpd start
echo "============================phpmyadmin install completed============================================"
}
#===============================================================================
#DESCRIPTION:install libiconv.
#USAGE:install_libiconv
#===============================================================================
function install_libiconv(){
if [ ! -d /usr/local/libiconv ];then
cd $cur_dir/untar/libiconv-1.14
./configure --prefix=/usr/local/libiconv
make
make install
fi
}

#===============================================================================
#DESCRIPTION:install lamp.
#USAGE:install_lamp
#===============================================================================
function install_lamp(){
rootness
disable_selinux
pre_installation_settings
download_files "httpd-2.2.22.tar.gz" "http://mirror.bit.edu.cn/apache//httpd/httpd-2.2.22.tar.gz"
if [ $mysqlv == 1 ];then
download_files "mysql-5.1.61.tar.gz" "http://mysql.ntu.edu.tw/Downloads/MySQL-5.1/mysql-5.1.61.tar.gz"
else
download_files "mysql-5.5.20.tar.gz" "http://dev.mysql.com/get/Downloads/MySQL-5.5/mysql-5.5.20.tar.gz/from/http://mysql.he.net/"
download_files "cmake-2.8.7.tar.gz" "http://www.cmake.org/files/v2.8/cmake-2.8.7.tar.gz"
download_files "bison-2.5.tar.gz" "http://ftp.gnu.org/gnu/bison/bison-2.5.tar.gz"
fi
if [ $phpv == 1 ];then
download_files "php-5.2.17.tar.gz" "http://cn.php.net/get/php-5.2.17.tar.gz/from/cn2.php.net/mirror"
else
download_files "php-5.3.10.tar.gz" "http://jp1.php.net/distributions/php-5.3.10.tar.gz"
fi
download_files "phpMyAdmin-3.4.9-all-languages.tar.gz" "http://llsmp-modify.googlecode.com/files/phpMyAdmin-3.4.9-all-languages.tar.gz"
download_files "libiconv-1.14.tar.gz" "http://ftp.gnu.org/pub/gnu/libiconv/libiconv-1.14.tar.gz"
#untar the tar.gz files
mkdir $cur_dir/untar
tar xzf httpd-2.2.22.tar.gz -C $cur_dir/untar
tar xzf phpMyAdmin-3.4.9-all-languages.tar.gz -C $cur_dir/untar
tar xzf libiconv-1.14.tar.gz -C $cur_dir/untar
install_apache
install_mysql
install_libiconv
install_php
install_phpmyadmin
\cp $cur_dir/lamp.sh /usr/bin/lamp
\cp $cur_dir/conf/httpd.logrotate /etc/logrotate.d/httpd
chmod +x $cur_dir/*.sh
echo "============================LAMP install completed============================================"
echo "mysql root password:$mysqlrootpwd"
echo "default web root:/home/www/default"
echo "For more information:www.centos.bz/lamp/"
exit 0
}
#===============================================================================
#DESCRIPTION:uninstall lamp.
#USAGE:uninstall_lamp
#===============================================================================
function uninstall_lamp(){
while true
do
read -p "(Before uninstall,please backup your data!Are you sure uninstall the lamp?[y/N]):" uninstall
case $uninstall in
y|Y|YES|yes|Yes)
uninstall=y
break
;;
n|N|no|NO|No)
uninstall=n
break
;;
*) echo Please enter only y or n
esac
done
if [ "$uninstall" = "y" ]  ;then
killall httpd
killall mysqld
killall vsftpd
rm -rf /usr/local/apache/  /etc/init.d/httpd /usr/local/apache /usr/sbin/httpd /usr/sbin/apachectl /var/log/httpd /var/lock/subsys/httpd /var/spool/mail/apache /etc/logrotate.d/httpd
rm -rf /usr/local/mysql/ /etc/my.cnf /etc/rc.d/init.d/mysqld /etc/ld.so.conf.d/mysql.conf /usr/bin/mysql /var/lock/subsys/mysql /var/spool/mail/mysql
rm -rf /usr/local/php/ /usr/lib/php 
rm -rf /usr/local/Zend/
rm -rf /home/www/default/phpmyadmin
rm -rf /etc/vsftpd.conf /etc/pam.d/ftp
rm -rf /root/sh /root/lamp /usr/bin/lamp
sed -i '\/usr\/local\/sbin\/vsftpd &/d' /etc/rc.d/rc.local
sed -i '\/sbin\/modprobe ip_conntrack_ftp/d' /etc/rc.d/rc.local
sed -i '\/sbin\/modprobe ip_nat_ftp/d' /etc/rc.d/rc.local
/sbin/iptables --flush
/etc/rc.d/init.d/iptables stop
echo "successfully uninstall lamp"
fi
}
#===============================================================================
#DESCRIPTION:add apache virtualhost.
#USAGE:vhost_add
#===============================================================================
function vhost_add(){
#1-define domain name
read -p "(Please input domain(default:www.centos.bz)):" domain
	if [ "$domain" = "" ]; then
		domain="www.centos.bz"
	fi
		if [ -f "/usr/local/apache/conf/vhost/$domain.conf" ]; then
	echo "$domain is exist!"
	exit
	fi
DocumentRoot="/home/www/$domain/web"
logsdir="/home/www/$domain/logs"
mkdir -p $DocumentRoot $logsdir
#2-create database or not	
while true
do
read -p "(Do you want to create database?[y/N]):" create
case $create in
y|Y|YES|yes|Yes)
read -p "(please input the database name):" dbname
read -p "(please set the password for mysql user $dbname):" mysqlpwd
create=y
break
;;
n|N|no|NO|No)
echo "not create database - you entered $create"
create=n
break
;;
*) echo Please enter only y or n
esac
done
#create database
mysqlroot_passwd=`cat /root/my.cnf`
if [ "$create" == "y" ];then
mysql -uroot -p"$mysqlroot_passwd"  <<EOF
CREATE DATABASE  IF NOT EXISTS \`$dbname\`;
GRANT ALL PRIVILEGES ON \`$dbname\` . * TO '$dbname'@'localhost' IDENTIFIED BY '$mysqlpwd';
GRANT ALL PRIVILEGES ON \`$dbname\` . * TO '$dbname'@'127.0.0.1' IDENTIFIED BY '$mysqlpwd';
FLUSH PRIVILEGES;
EOF
fi
#create vhost configuration file
cat >/usr/local/apache/conf/vhost/$domain.conf<<eof
<virtualhost *:80>
ServerName  $domain
ServerAlias  $domain 
DocumentRoot  $DocumentRoot
CustomLog $logsdir/access.log combined
DirectoryIndex index.html index.php
<Directory $DocumentRoot>
Options +Includes -Indexes
AllowOverride All
Order Deny,Allow
Allow from All
php_admin_value open_basedir $DocumentRoot:/tmp
</Directory>
</virtualhost>
eof
service httpd reload > /dev/null 2>&1
echo "successfully create $domain vhost"
echo "######################### information about your website ############################"
echo "The DocumentRoot:$DocumentRoot"
echo "The Logsdir:$logsdir"
echo "mysql dbname:$dbname and password:$mysqlpwd"
}
#===============================================================================
#DESCRIPTION:remove apache virtualhost.
#USAGE:vhost_del
#===============================================================================
function vhost_del(){
read -p "(Please input domain you'll delete):" domain
rm -f /usr/local/apache/conf/vhost/$domain.conf
service httpd reload > /dev/null 2>&1
echo "successfully delete $domain vhost"
echo "you need to remove site directory manually!"
}
#===============================================================================
#DESCRIPTION:list apache virtualhost.
#USAGE:vhost_list
#===============================================================================
function vhost_list(){
ls /usr/local/apache/conf/vhost/ | cut -f 1,2,3 -d "."
}
#===============================================================================
#DESCRIPTION:add,del,list ftp user.
#USAGE:ftp (add|del|list)
#===============================================================================
function ftp(){
case "$faction" in
add)
read -p "(Please input ftpuser name):" ftpuser
read -p "(Please input ftpuser password):" ftppwd
read -p "(Please input ftpuser root directory):" ftproot
useradd -d $ftproot -g ftp -c vsftpd -s /sbin/nologin  $ftpuser
echo $ftpuser:$ftppwd |chpasswd
if [ -d "$ftproot" ]; then
chmod -R 755 $ftproot
chown -R $ftpuser:ftp $ftproot
fi
echo "successfully create ftpuser $ftpuser"
echo "the ftp root directory is $ftproot"
;;
del)
read -p "(Please input the ftpuser you'll delete):" ftpuser
userdel $ftpuser
echo "successfully delete ftpuser $ftpuser"
;;
list)
printf "FTPUser\t\tRoot Directory\n"
cat /etc/passwd | grep vsftpd | awk 'BEGIN {FS=":"} {print $1"\t\t"$6}'
;;
*)
echo "Usage:add|del|list"
exit 1
esac
}
action=$1
[  -z $1 ] && action=install
case "$action" in
install)
    install_lamp
    ;;
uninstall)
    uninstall_lamp
    ;;
add)
   vhost_add
    ;;
del)
   vhost_del
    ;;
list)
   vhost_list
    ;;
 ftp)
  faction=$2
    ftp
        ;;
*)
    echo "Usage: `basename $0` {install|uninstall|add|del|list|ftp(add,del,list))"
    ;;
esac